
try:
    from .version import __version__
except:
    pass

from .mm import get_data
from .mm import get_models
from .mm import nrg_format_path
from .mm import highest_quality_repeat
from .mm import average_blind_qc_by_modality
from .mm import match_modalities
from .mm import outlierness_by_modality
from .mm import dewarp_imageset
from .mm import super_res_mcimage
from .mm import dipy_dti_recon
from .mm import segment_timeseries_by_meanvalue
from .mm import wmh
from .mm import neuromelanin
from .mm import joint_dti_recon
from .mm import resting_state_fmri_networks
from .mm import t1_based_dwi_brain_extraction
from .mm import dwi_deterministic_tracking
from .mm import dwi_closest_peak_tracking
from .mm import dwi_streamline_connectivity
from .mm import hierarchical_modality_summary
from .mm import dwi_streamline_pairwise_connectivity
from .mm import write_bvals_bvecs
from .mm import mm
from .mm import mm_nrg
from .mm import mm_csv
from .mm import write_mm
from .mm import mask_snr
from .mm import crop_mcimage
from .mm import alff_image
from .mm import alffmap
from .mm import spec_taper
from .mm import spec_ci
from .mm import spec_pgram
from .mm import plot_spec
from .mm import down2iso
from .mm import tra_initializer
from .mm import mm_read
from .mm import mm_read_to_3d
from .mm import image_write_with_thumbnail
from .mm import nrg_filelist_to_dataframe
from .mm import bind_wide_mm_csvs
from .mm import augment_image
from .mm import boot_wmh
from .mm import threaded_bind_wide_mm_csvs
from .mm import average_mm_df
from .mm import get_names_from_data_frame
from .mm import read_mm_csv
from .mm import assemble_modality_specific_dataframes
from .mm import mc_denoise
from .mm import mc_reg
from .mm import dti_reg
from .mm import timeseries_reg
from .mm import concat_dewarp
from .mm import mc_resample_image_to_target
from .mm import trim_dti_mask
from .mm import impute_fa
from .mm import get_average_dwi_b0
from .mm import dti_template
from .mm import merge_dwi_data
from .mm import merge_timeseries_data
from .mm import bvec_reorientation
from .mm import tsnr
from .mm import dvars
from .mm import slice_snr
from .mm import quick_viz_mm_nrg
from .mm import blind_image_assessment
from .mm import get_average_rsf
from .mm import version
from .mm import best_mmm
from .mm import nrg_2_bids
from .mm import bids_2_nrg
from .mm import parse_nrg_filename
from .mm import novelty_detection_ee
from .mm import novelty_detection_svm
from .mm import novelty_detection_lof
from .mm import novelty_detection_loop
from .mm import novelty_detection_quantile
from .mm import generate_mm_dataframe
from .mm import collect_blind_qc_by_modality
from .mm import get_valid_modalities



import sys, os
import unittest
import tensorflow as tf
import ants
import antspynet
import antspymm

import tempfile
import shutil

mdlfn = antspymm.get_data( "brainSR", target_extension=".h5")
mdl = tf.keras.models.load_model( mdlfn )
img = ants.image_read( antspymm.get_data( "I1499279_Anon_20210819142214_5", target_extension=".nii.gz") )
lod = 16
imgd = ants.resample_image( img, (lod,lod,lod,lod), use_voxels=True)
srimg = antspymm.super_res_mcimage( imgd, mdl, verbose=False )

testingClass = unittest.TestCase( )

testingClass.assertEqual(
    srimg.shape[0], lod*2, "dimension incorrect")



import os
os.environ["TF_NUM_INTEROP_THREADS"] = "8"
os.environ["TF_NUM_INTRAOP_THREADS"] = "8"
os.environ["ITK_GLOBAL_DEFAULT_NUMBER_OF_THREADS"] = "8"
from os.path import exists
from dipy.io.image import save_nifti, load_nifti
import antspymm
import antspyt1w
import antspynet
import ants
import pandas as pd
import tensorflow as tf
from tempfile import mktemp
import numpy as np
import antspymm
print(" Load in JHU atlas and labels ")
ex_path = os.path.expanduser( "~/.antspyt1w/" )
ex_path_mm = os.path.expanduser( "~/.antspymm/" )
JHU_atlas = ants.image_read( ex_path + 'JHU-ICBM-FA-1mm.nii.gz' ) # Read in JHU atlas
JHU_labels = ants.image_read( ex_path + 'JHU-ICBM-labels-1mm.nii.gz' ) # Read in JHU labels
#### Load in data ####
print("Load in subject data ...")
lrid = ex_path_mm + "I1499279_Anon_20210819142214_5"
rlid = ex_path_mm + "I1499337_Anon_20210819142214_6"
t1id = ex_path_mm + "t1_rand.nii.gz"
print("Load in image L-R")
img_LR_in = ants.image_read( lrid + '.nii.gz') # LR dwi image
img_LR_bval = lrid + '.bval' # bval
img_LR_bvec = lrid + '.bvec'
print("Load in image R-L")
img_RL_in = ants.image_read( rlid + '.nii.gz' ) # RL dwi image
img_RL_bval = lrid + '.bval' # bval
img_RL_bvec = lrid + '.bvec'

print("brain extract the T1")
t1wh = ants.iMath( ants.image_read( t1id ) , 'Normalize' )
mybxt = antspyt1w.brain_extraction( t1wh )
t1w = t1wh * mybxt

print("build the DTI templates")
a1b,a1w=antspymm.get_average_dwi_b0(img_LR_in)
a2b,a2w=antspymm.get_average_dwi_b0(img_RL_in)
btpB0, btpDW = antspymm.dti_template(
        b_image_list=[a1b,a2b],
        w_image_list=[a1w,a2w],
        iterations=2, verbose=True )

print("bxt the DTI template space")
reg = ants.registration( btpDW, t1w, 'SyNBold', verbose=False)
mask = ants.apply_transforms( btpDW, mybxt, reg['fwdtransforms'], interpolator='nearestNeighbor')

print("Begin joint DTI recon")
myoutx = antspymm.joint_dti_recon(
        img_LR_in,
        img_LR_bval,
        img_LR_bvec,
        jhu_atlas = JHU_atlas,
        jhu_labels = JHU_labels,
        reference_B0=btpB0,
        reference_DWI=btpDW,
        srmodel = None,
        img_RL = img_RL_in,
        bval_RL = img_RL_bval,
        bvec_RL = img_RL_bvec,
        motion_correct = 'Rigid',
        brain_mask = mask,
        denoise = False,
        verbose = True )

if True:
    ants.image_write( myoutx['recon_fa'], '/tmp/temp1fa.nii.gz'  )
    ants.image_write( myoutx['recon_md'], '/tmp/temp1md.nii.gz'  )
    ants.image_write( myoutx['dwi_LR_dewarped'], '/tmp/temp1moco.nii.gz'  )
    ants.image_write( myoutx['dtrecon_LR_dewarp']['RGB'], '/tmp/temp1rgb.nii.gz'  )



import sys, os
import unittest

os.environ["TF_NUM_INTEROP_THREADS"] = "8"
os.environ["TF_NUM_INTRAOP_THREADS"] = "8"
os.environ["ITK_GLOBAL_DEFAULT_NUMBER_OF_THREADS"] = "8"

import tempfile
import shutil
import tensorflow as tf
import antspymm
import antspyt1w
import antspynet
import ants
import numpy as np




# FIXME - need to return FD and other motion parameters from dewarp function
# then incorporate those parameters in this example

testingClass = unittest.TestCase( )
islocal = False
id1 = "LS2001_3T_rfMRI_REST1_LR_gdc"
id2 = "LS2001_3T_rfMRI_REST1_RL_gdc"
img1 = ants.image_read( antspymm.get_data( id1, target_extension=".nii.gz") )
img2 = ants.image_read( antspymm.get_data( id2, target_extension=".nii.gz") )

if 'dwp' not in globals() and False:
    dwp = antspymm.dewarp_imageset( [img1,img2], iterations=3, padding=0,
        target_idx = [10,11,12],
        syn_sampling = 20, syn_metric='mattes',
        type_of_transform = 'SyN',
        total_sigma = 0.0, random_seed=1,
        reg_iterations = [200,50,20] )
    if islocal:
      print('rsfmri dewarp done')
      ants.image_write( dwp['dewarped'][0], './rsfmridewarped0.nii.gz' )
      ants.image_write( dwp['dewarped'][1], './rsfmridewarped1.nii.gz' )

# now process fMRI as usual --- do we concatenate the two dewarped images?
# for now, just processing dwp0
import pandas as pd
und = ants.get_average_of_timeseries( img1 ) # dwp['dewarpedmean']
bmask = antspynet.brain_extraction( und, 'bold' ).threshold_image( 0.3, 1.0 )
powers_areal_mni_itk = pd.read_csv(antspymm.get_data('powers_mni_itk', target_extension=".csv")) # power coordinates
t1fn = antspymm.get_data( 'LS2001_3T_T1w_MPR1_gdc' , target_extension='.nii.gz' )
print("do t1")
t1 = ants.image_read( t1fn ).n3_bias_field_correction( 8 ).n3_bias_field_correction( 4 )
t1bxt = antspynet.brain_extraction( t1, 't1' ).threshold_image( 0.3, 1.0 )
t1seg = antspynet.deep_atropos( t1 )
t1segmentation = t1seg['segmentation_image']
print("do rsf")
rsf = antspymm.resting_state_fmri_networks(
  img1, t1 * t1bxt, t1segmentation, f=[0.03, 0.08], spa=1.5, spt=0.5, nc=6)
